==> s-2.0.58.tgz: package/CONTRIBUTORS.md <==
# Serverless Devs Contributors

> Thank you for your support and recognition of serverless devs. Serverless devs is committed to creating an active and open serverless developer ecosystem, providing more simple and easy-to-use serverless developer tools for more serverless developers.

<center>
    <table>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/4457084?s=60&v=4" width="20%" style="min-width: 100px"><br>
                <p>hanxie-crypto<br><a href="https://github.com/hanxie-crypto"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/46711?v=4" width="20%" style="min-width: 100px"><br>
                <p>linux-china<br><a href="http://github.com/anycodes">Github</a> | <a href="http://rsocketbyexample.info">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/21079031?v=4" width="20%" style="min-width: 100px"><br>
                <p>anycodes<br><a href="http://github.com/anycodes">Github</a> | <a href="http://faas.net.cn">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/56686088?v=4" width="20%" style="min-width: 100px"><br>
                <p>wss-git<br><a href="https://github.com/wss-git">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/31543505?v=4" width="20%" style="min-width: 100px"><br>
                <p>hanyang-sh<br><a href="http://github.com/hanyang-sh">Github</a> | <a href="https://hanyang-sh.github.io/">Blog</a></p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/2697433?v=4" width="20%" style="min-width: 100px"><br>
                <p>dengshenyu<br><a href="https://github.com/dengshenyu"> Github</a> | <a href="http://www.dengshenyu.com">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/52195264?v=4" width="20%" style="min-width: 100px"><br>
                <p>git-qfzhang<br><a href="http://github.com/git-qfzhang">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/21079031?v=4" width="20%" style="min-width: 100px"><br>
                <p>heimanba<br><a href="https://avatars.githubusercontent.com/u/5129967?v=4">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/10919599?v=4" width="20%" style="min-width: 100px"><br>
                <p>rsonghuster<br><a href="https://github.com/rsonghuster">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/5166366?v=4" width="20%" style="min-width: 100px"><br>
                <p>Tang Xianbin<br><a href="http://github.com/XianB">Github</a> | <a href="https://hanyang-sh.github.io/">Blog</a></p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/13564730?v=4" width="20%" style="min-width: 100px"><br>
                <p>cong876<br><a href="https://github.com/cong876"> Github</a> | <a href="http://cong876.github.io/">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/43135116?v=4" width="20%" style="min-width: 100px"><br>
                <p>gongjl88<br><a href="http://github.com/gongjl88">Github</a> | <a href="https://www.blog.loveapple.top"> Blog </a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/5129967?v=4" width="20%" style="min-width: 100px"><br>
                <p>wangbow<br><a href="http://github.com/wangbow">Github</a> | <a href="https://juejin.im/user/58e8a667ac502e4957bcddbe">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/30379999?v=4" width="20%" style="min-width: 100px"><br>
                <p>Herbbbb<br><a href="https://github.com/Herbbbb">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/62200750?v=4" width="20%" style="min-width: 100px"><br>
                <p>janw<br><a href="http://github.com/jjangww">Github</a> | Blog</p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/48934955?v=4" width="20%" style="min-width: 100px"><br>
                <p>Ellison<br><a href="https://github.com/coco-super"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/23737468?v=4" width="20%" style="min-width: 100px"><br>
                <p>黄沐<br><a href="https://github.com/huangfushan"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/84389274?v=4" width="20%" style="min-width: 100px"><br>
                <p>siyuniuali<br><a href="https://github.com/siyuniuali"> siyuniuali</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/85347842?v=4" width="20%" style="min-width: 100px"><br>
                <p>Laura-monkey<br><a href="https://github.com/Laura-monkey"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/85340348?v=4" width="20%" style="min-width: 100px"><br>
                <p>jingyan0705<br><a href="https://github.com/jingyan0705"> Github</a> | Blog</p>
            </td>
        </tr>
         <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/16363180?v=4" width="20%" style="min-width: 100px"><br>
                <p>邓超<br><a href="https://github.com/DevDengChao"> Github</a> | Blog</p>
            </td>
        </tr>
    </table>
</center>

==> s-2.0.60.tgz: package/CONTRIBUTORS.md <==
# Serverless Devs Contributors

> Thank you for your support and recognition of serverless devs. Serverless devs is committed to creating an active and open serverless developer ecosystem, providing more simple and easy-to-use serverless developer tools for more serverless developers.

<center>
    <table>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/4457084?s=60&v=4" width="20%" style="min-width: 100px"><br>
                <p>hanxie-crypto<br><a href="https://github.com/hanxie-crypto"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/46711?v=4" width="20%" style="min-width: 100px"><br>
                <p>linux-china<br><a href="http://github.com/linux-china">Github</a> | <a href="http://rsocketbyexample.info">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/21079031?v=4" width="20%" style="min-width: 100px"><br>
                <p>anycodes<br><a href="http://github.com/anycodes">Github</a> | <a href="http://faas.net.cn">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/56686088?v=4" width="20%" style="min-width: 100px"><br>
                <p>wss-git<br><a href="https://github.com/wss-git">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/31543505?v=4" width="20%" style="min-width: 100px"><br>
                <p>hanyang-sh<br><a href="http://github.com/hanyang-sh">Github</a> | <a href="https://hanyang-sh.github.io/">Blog</a></p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/2697433?v=4" width="20%" style="min-width: 100px"><br>
                <p>dengshenyu<br><a href="https://github.com/dengshenyu"> Github</a> | <a href="http://www.dengshenyu.com">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/52195264?v=4" width="20%" style="min-width: 100px"><br>
                <p>git-qfzhang<br><a href="http://github.com/git-qfzhang">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/21079031?v=4" width="20%" style="min-width: 100px"><br>
                <p>heimanba<br><a href="https://avatars.githubusercontent.com/u/5129967?v=4">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/10919599?v=4" width="20%" style="min-width: 100px"><br>
                <p>rsonghuster<br><a href="https://github.com/rsonghuster">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/5166366?v=4" width="20%" style="min-width: 100px"><br>
                <p>Tang Xianbin<br><a href="http://github.com/XianB">Github</a> | <a href="https://hanyang-sh.github.io/">Blog</a></p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/13564730?v=4" width="20%" style="min-width: 100px"><br>
                <p>cong876<br><a href="https://github.com/cong876"> Github</a> | <a href="http://cong876.github.io/">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/43135116?v=4" width="20%" style="min-width: 100px"><br>
                <p>gongjl88<br><a href="http://github.com/gongjl88">Github</a> | <a href="https://www.blog.loveapple.top"> Blog </a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/5129967?v=4" width="20%" style="min-width: 100px"><br>
                <p>wangbow<br><a href="http://github.com/wangbow">Github</a> | <a href="https://juejin.im/user/58e8a667ac502e4957bcddbe">Blog</a></p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/30379999?v=4" width="20%" style="min-width: 100px"><br>
                <p>Herbbbb<br><a href="https://github.com/Herbbbb">Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/62200750?v=4" width="20%" style="min-width: 100px"><br>
                <p>janw<br><a href="http://github.com/jjangww">Github</a> | Blog</p>
            </td>
        </tr>
        <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/48934955?v=4" width="20%" style="min-width: 100px"><br>
                <p>Ellison<br><a href="https://github.com/coco-super"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/23737468?v=4" width="20%" style="min-width: 100px"><br>
                <p>黄沐<br><a href="https://github.com/huangfushan"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/84389274?v=4" width="20%" style="min-width: 100px"><br>
                <p>siyuniuali<br><a href="https://github.com/siyuniuali"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/85347842?v=4" width="20%" style="min-width: 100px"><br>
                <p>Laura-monkey<br><a href="https://github.com/Laura-monkey"> Github</a> | Blog</p>
            </td>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/85340348?v=4" width="20%" style="min-width: 100px"><br>
                <p>jingyan0705<br><a href="https://github.com/jingyan0705"> Github</a> | Blog</p>
            </td>
        </tr>
         <tr>
            <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/16363180?v=4" width="20%" style="min-width: 100px"><br>
                <p>邓超<br><a href="https://github.com/DevDengChao"> Github</a> | Blog</p>
            </td>
             <td align="center" width="20%">
                <img src="https://avatars.githubusercontent.com/u/24624391?v=4" width="20%" style="min-width: 100px"><br>
                <p>吴培泽<br><a href="https://github.com/wupz-repo"> Github</a> | <a href="https://wupeize.com">Blog</a></p>
            </td>
        </tr>
    </table>
</center>
